Learn R Programming

tolerance (version 1.2.0)

dparetotol.int: Discrete Pareto Tolerance Intervals

Description

Provides 1-sided or 2-sided tolerance intervals for data distributed according to the discrete Pareto distribution.

Usage

dparetotol.int(x, m = NULL, alpha = 0.05, P = 0.99, side = 1, ...)

Arguments

x
A vector of raw data which is distributed according to a discrete Pareto distribution.
m
The number of observations in a future sample for which the tolerance limits will be calculated. By default, m = NULL and, thus, m will be set equal to the original sample size.
alpha
The level chosen such that 1-alpha is the confidence level.
P
The proportion of the population to be covered by this tolerance interval.
side
Whether a 1-sided or 2-sided tolerance interval is required (determined by side = 1 or side = 2, respectively).
...
Additional arguments passed to the dpareto.ll function, which is used for maximum likelihood estimation.

Value

dparetotol.int returns a data frame with the following items:
alpha
The specified significance level.
P
The proportion of the population covered by this tolerance interval.
theta
MLE for the shape parameter theta.
1-sided.lower
The 1-sided lower tolerance bound. This is given only if side = 1.
1-sided.upper
The 1-sided upper tolerance bound. This is given only if side = 1.
2-sided.lower
The 2-sided lower tolerance bound. This is given only if side = 2.
2-sided.upper
The 2-sided upper tolerance bound. This is given only if side = 2.

Details

The discrete Pareto is a discretized of the continuous Type II Pareto distribution (also called the Lomax distribution). Discrete Pareto distributions are heavily right-skewed distributions and potentially good models for discrete lifetime data and extremes in count data. For most practical applications, one will typically be interested in 1-sided upper bounds.

References

Young, D. S., Naghizadeh Qomi, M., and Kiapour, A. (2016), Approximate Discrete Pareto Tolerance Limits for Characterizing Extremes in Count Data, submitted.

See Also

DiscretePareto, dpareto.ll

Examples

Run this code
## 95%/95% 1-sided tolerance intervals for data assuming 
## the discrete Pareto distribution.

set.seed(100)

x <- rdpareto(n = 500, theta = 0.5)
out <- dparetotol.int(x, alpha = 0.05, P = 0.95, side = 1)
out

Run the code above in your browser using DataLab