Learn R Programming

tolerance (version 1.2.0)

hypertol.int: Hypergeometric Tolerance Intervals

Description

Provides 1-sided or 2-sided tolerance intervals for hypergeometric random variables. From a sampling without replacement perspective, these limits use the proportion of units from group A (e.g., "black balls" in an urn) in a sample to bound the number of potential units drawn from group A in a future sample taken from the universe.

Usage

hypertol.int(x, n, N, m = NULL, alpha = 0.05, P = 0.99, side = 1, method = c("EX", "LS", "CC"))

Arguments

x
The number of units from group A in the sample. Can be a vector, in which case the sum of x is used.
n
The size of the random sample of units selected.
N
The population size.
m
The quantity of units to be sampled from the universe for a future study. If m = NULL, then the tolerance limits will be constructed assuming n for this quantity.
alpha
The level chosen such that 1-alpha is the confidence level.
P
The proportion of units from group A in future samples of size m to be covered by this tolerance interval.
side
Whether a 1-sided or 2-sided tolerance interval is required (determined by side = 1 or side = 2, respectively).
method
The method for calculating the lower and upper confidence bounds, which are used in the calculation of the tolerance bounds. The default method is "EX", which is an exact-based method. "LS" is the large-sample method. "CC" gives a continuity-corrected version of the large-sample method.

Value

hypertol.int returns a data frame with items:
alpha
The specified significance level.
P
The proportion of units from group A in future samples of size m.
rate
The sampling rate determined by n/N.
p.hat
The proportion of units in the sample from group A, calculated by x/n.
1-sided.lower
The 1-sided lower tolerance bound. This is given only if side = 1.
1-sided.upper
The 1-sided upper tolerance bound. This is given only if side = 1.
2-sided.lower
The 2-sided lower tolerance bound. This is given only if side = 2.
2-sided.upper
The 2-sided upper tolerance bound. This is given only if side = 2.

References

Brown, L. D., Cai, T. T., and DasGupta, A. (2001), Interval Estimation for a Binomial Proportion, Statistical Science, 16, 101--133.

Eichenberger, P., Hulliger, B., and Potterat, J. (2011), Two Measures for Sample Size Determination, Survey Research Methods, 5, 27--37.

Young, D. S. (2014), Tolerance Intervals for Hypergeometric and Negative Hypergeometric Variables, Sankhya: The Indian Journal of Statistics, Series B, to appear.

See Also

acc.samp, Hypergeometric

Examples

Run this code
## 90%/95% 1-sided and 2-sided hypergeometric tolerance 
## intervals for a future sample of 30 when the universe
## is of size 100.

hypertol.int(x = 15, n = 50, N = 100, m = 30, alpha = 0.10, 
             P = 0.95, side = 1, method = "LS")
hypertol.int(x = 15, n = 50, N = 100, m = 30, alpha = 0.10, 
             P = 0.95, side = 1, method = "CC")
hypertol.int(x = 15, n = 50, N = 100, m = 30, alpha = 0.10, 
             P = 0.95, side = 2, method = "LS")
hypertol.int(x = 15, n = 50, N = 100, m = 30, alpha = 0.10, 
             P = 0.95, side = 2, method = "CC")
 

Run the code above in your browser using DataLab