- x
An nxp matrix of data assumed to be drawn from a p-dimensional multivariate distribution. n pertains to the sample size.
- alpha
The level chosen such that 1-alpha is the confidence level. Note that if a (P, 1-alpha) tolerance region is required, then both alpha and P must be specified, but Beta must be set to NULL.
- P
The proportion of the population to be covered by this tolerance interval. Note that if a (P, 1-alpha) tolerance region is required, then both alpha and P must be specified, but Beta must be set to NULL.
- Beta
The confidence level for a beta-expectation tolerance region. Note that if a beta-expectation tolerance region is required, then Beta must be specified, but both alpha and P must be set to NULL.
- depth.fn
The data depth function used to perform the ordering of the multivariate data. Thus function must be coded in such a way that the first argument is multivariate data for which to calculate the depth values and the second argument is the original multivariate sample, x. For the purpose of this tolerance region calculation, these two arguments should both be the original multivariate sample.
- adjust
Whether an adjustment should be made during an intermediate calculation for determining the number of points that need to be included in the multivariate region. If adjust = "no", the default, then no adjustment is made during the intermediate calculation. If adjust = "floor", then the intermediate calculation is rounded down to the next nearest integer. If adjust = "ceiling", then the intermediate calculation is rounded up to the next nearest integer.
- type
The type of multivariate hyperrectangular region to calculate. If type = "central", then two-sided intervals are reported for each dimension of the data x. If type = "semispace", then a combination of one-sided intervals and two-sided intervals are reported for the dimensions of x. Which interval is calculated for each dimension in this latter setting is dictated by the semi.order argument.
- semi.order
If type = "semispace", then this argument must be specified. This argument is a list of length 3, such that each element gives the indices of the dimensions of x for which the type of interval should be calculated. Indices specified for the element of lower will return one-sided lower limits for those dimensions, indices specified for the element of center will return two-sided intervals for those dimensions, and indices specified for the element of upper will return one-sided upper limits for those dimensions.
- L
If type = "semispace", these are the lower limits for any dimensions for which one requests one-sided upper limits.
- U
If type = "semispace", these are the upper limits for any dimensions for which one requests one-sided lower limits.
- ...
Additional arguments passed to the depth.fn function.