Learn R Programming

tolerance (version 1.1.1)

nptol.int: Nonparametric Tolerance Intervals

Description

Provides 1-sided or 2-sided nonparametric (i.e., distribution-free) tolerance intervals for any continuous data set.

Usage

nptol.int(x, alpha = 0.05, P = 0.99, side = 1,
          method = c("WILKS", "WALD", "HM", "YM"), 
          upper = NULL, lower = NULL)

Arguments

x
A vector of data which no distributional assumptions are made. The data is only assumed to come from a continuous distribution.
alpha
The level chosen such that 1-alpha is the confidence level.
P
The proportion of the population to be covered by this tolerance interval.
side
Whether a 1-sided or 2-sided tolerance interval is required (determined by side = 1 or side = 2, respectively).
method
The method for determining which indices of the ordered observations will be used for the tolerance intervals. "WILKS" is the Wilks method, which produces tolerance bounds symmetric about the observed center of the data by using the b
upper
The upper bound of the data. When NULL, then the maximum of x is used. If method = "YM" and extrapolation is performed, then upper will be greater than the maximum.
lower
The lower bound of the data. When NULL, then the minimum of x is used. If method = "YM" and extrapolation is performed, then lower will be less than the maximum.

Value

  • nptol.int returns a data frame with items:
  • alphaThe specified significance level.
  • PThe proportion of the population covered by this tolerance interval.
  • 1-sided.lowerThe 1-sided lower tolerance bound. This is given only if side = 1.
  • 1-sided.upperThe 1-sided upper tolerance bound. This is given only if side = 1.
  • 2-sided.lowerThe 2-sided lower tolerance bound. This is given only if side = 2.
  • 2-sided.upperThe 2-sided upper tolerance bound. This is given only if side = 2.

Details

For the Young-Mathew method, interpolation or extrapolation is performed. When side = 1, two intervals are given: one based on linear interpolation/extrapolation of order statistics (OS-Based) and one based on fractional order statistics (FOS-Based). When side = 2, only an interval based on linear interpolation/extrapolation of order statistics is given.

References

Bury, K. (1999), Statistical Distributions in Engineering, Cambridge University Press. Hahn, G. J. and Meeker, W. Q. (1991), Statistical Intervals: A Guide for Practitioners, Wiley-Interscience. Wald, A. (1943), An Extension of Wilks' Method for Setting Tolerance Limits, The Annals of Mathematical Statistics, 14, 45--55. Wilks, S. S. (1941), Determination of Sample Sizes for Setting Tolerance Limits, The Annals of Mathematical Statistics, 12, 91--96.

Young, D. S. and Mathew, T. (2014), Improved Nonparametric Tolerance Intervals Based on Interpolated and Extrapolated Order Statistics, Journal of Nonparametric Statistics, 26, 415--432.

See Also

distfree.est, npregtol.int

Examples

Run this code
## 90\%/95\% 2-sided nonparametric tolerance intervals for a 
## sample of size 20. 

set.seed(100)
x <- rlogis(20, 5, 1)
out <- nptol.int(x = x, alpha = 0.10, P = 0.95, side = 1,
                 method = "WILKS", upper = NULL, lower = NULL)
out

plottol(out, x, plot.type = "both", side = "two", x.lab = "X")

Run the code above in your browser using DataLab