Learn R Programming

tolerance (version 1.1.1)

poislind.ll: Maximum Likelihood Estimation for the Discrete Poisson-Lindley Distribution

Description

Performs maximum likelihood estimation for the parameter of the Poisson-Lindley distribution.

Usage

poislind.ll(x, theta = NULL, ...)

Arguments

x
A vector of raw data which is distributed according to a Poisson-Lindley distribution.
theta
Optional starting value for the parameter. If NULL, then the method of moments estimator is used.
...
Additional arguments passed to the mle function.

Value

  • See the help file for mle to see how the output is structured.

Details

The discrete Poisson-Lindley distribution is a compound distribution that, potentially, provides a better fit for count data relative to the traditional Poisson and negative binomial distributions.

References

Ghitany, M. E. and Al-Mutairi, D. K. (2009), Estimation Methods for the Discrete Poisson-Lindley Distribution, Journal of Statistical Computation and Simulation, 79, 1--9.

Sankaran, M. (1970), The Discrete Poisson-Lindley Distribution, Biometrics, 26, 145--149.

See Also

mle, PoissonLindley

Examples

Run this code
## Maximum likelihood estimation for randomly generated data
## from the Poisson-Lindley distribution. 

require(stats4)

set.seed(100)

pl.data <- rpoislind(n = 500, theta = 0.5)
out.pl <- poislind.ll(pl.data)
coef(out.pl)
vcov(out.pl)

Run the code above in your browser using DataLab