Learn R Programming

tolerance (version 1.2.0)

poislindtol.int: Poisson-Lindley Tolerance Intervals

Description

Provides 1-sided or 2-sided tolerance intervals for data distributed according to the Poisson-Lindley distribution.

Usage

poislindtol.int(x, m = NULL, alpha = 0.05, P = 0.99, side = 1, ...)

Arguments

x
A vector of raw data which is distributed according to a Poisson-Lindley distribution.
m
The number of observations in a future sample for which the tolerance limits will be calculated. By default, m = NULL and, thus, m will be set equal to the original sample size.
alpha
The level chosen such that 1-alpha is the confidence level.
P
The proportion of the population to be covered by this tolerance interval.
side
Whether a 1-sided or 2-sided tolerance interval is required (determined by side = 1 or side = 2, respectively).
...
Additional arguments passed to the poislind.ll function, which is used for maximum likelihood estimation.

Value

poislindtol.int returns a data frame with the following items:
alpha
The specified significance level.
P
The proportion of the population covered by this tolerance interval.
theta
MLE for the shape parameter theta.
1-sided.lower
The 1-sided lower tolerance bound. This is given only if side = 1.
1-sided.upper
The 1-sided upper tolerance bound. This is given only if side = 1.
2-sided.lower
The 2-sided lower tolerance bound. This is given only if side = 2.
2-sided.upper
The 2-sided upper tolerance bound. This is given only if side = 2.

Details

The discrete Poisson-Lindley distribution is a compound distribution that, potentially, provides a better fit for count data relative to the traditional Poisson and negative binomial distributions. Poisson-Lindley distributions are heavily right-skewed distributions. For most practical applications, one will typically be interested in 1-sided upper bounds.

References

Naghizadeh Qomi, M., Kiapour, A., and Young, D. S. (2015), Approximate Tolerance Intervals for the Discrete Poisson-Lindley Distribution, Journal of Statistical Computation and Simulation, 86, 841--854.

See Also

PoissonLindley, poislind.ll

Examples

Run this code
## 90%/90% 1-sided tolerance intervals for data assuming 
## the Poisson-Lindley distribution.

x <- c(rep(0, 447), rep(1, 132), rep(2, 42), rep(3, 21), 
       rep(4, 3), rep(5, 2))
out <- poislindtol.int(x, alpha = 0.10, P = 0.90, side = 1)
out

Run the code above in your browser using DataLab