Usage
bayesnormtol.int(x = NULL, norm.stats = list(x.bar = NA,
s = NA, n = NA), alpha = 0.05, P = 0.99,
side = 1, method = c("HE", "HE2", "WBE",
"ELL", "KM", "EXACT", "OCT"), m = 50,
hyper.par = list(mu.0 = NULL,
sig2.0 = NULL, m.0 = NULL, n.0 = NULL))Arguments
x
A vector of data which is distributed according to a normal distribution.
norm.stats
An optional list of statistics that can be provided in-lieu of the full dataset. If provided, the user must specify all three components: the sample mean (x.bar), the sample standard deviation (s), and the sample size (n
alpha
The level chosen such that 1-alpha is the confidence level.
P
The proportion of the population to be covered by this tolerance interval.
side
Whether a 1-sided or 2-sided tolerance interval is required (determined by side = 1 or side = 2,
respectively).
method
The method for calculating the k-factors. The k-factor for the 1-sided tolerance intervals
is performed exactly and thus is the same for the chosen method. "HE" is the
Howe method and is often viewed as being extremely accurate, even fo
m
The maximum number of subintervals to be used in the integrate function. This is necessary only for method = "EXACT" and method = "OCT". The larger
the number, the more accurate the solution. Too low of a value
hyper.par
A list consisting of the hyperparameters for the conjugate prior: the hyperparameters for the mean (mu.0 and n.0) and the hyperparameters for the variance (sig2.0 and m.0).